/*
 * LED image
 *  for Wi-Fi view & select
 */
package jp.gr.java_conf.j_sota.wifiviewandselect;

import android.content.Context;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;

public class LedImage {

	private static final float LED_SIZE_IN_DIP = 20f;

	private Context mContext;
	private Bitmap mLedImageBitmap;

	/**
	 * Constructor.
	 * @param context	Context
	 */
	public LedImage(Context context) {
		mContext = context;
	}

	/**
	 * Make LED Image.
	 * @param color
	 * @return LED image bitmap
	 */
	public Bitmap getLedImage(int color) {
		// Calculate pixel size
		Resources resources = mContext.getResources();
		float density = resources.getDisplayMetrics().density;
		int pixel = (int) (LED_SIZE_IN_DIP * density + 0.5f);

		// Make Bitmap, Canvas, Paint
		mLedImageBitmap = Bitmap.createBitmap(pixel, pixel, Bitmap.Config.ARGB_8888);
		Canvas canvas = new Canvas(mLedImageBitmap);
		Paint paint = new Paint();

		// Draw LED image
		paint.setColor(Color.BLACK);
		paint.setAntiAlias(true);
		canvas.drawCircle(pixel/2, pixel/2, pixel/2, paint);

		paint.setColor(color);
		paint.setAntiAlias(true);
		canvas.drawCircle(pixel/2, pixel/2, pixel/2-1, paint);

		return mLedImageBitmap;
	}
}
